@@ -26,7 +26,7 @@
 ##  shiela-install.sh: repository install program (syntax: Bourne-Shell)
 ##
 
-version="1.0.2"
+version="1.0.3"
 
 prefix="@prefix@"
 bindir="@bindir@"
@@ -594,7 +594,7 @@ cvs_file tst taginfo
 run "(echo ''; echo 'ALL $V_tool_shiela --hook=taginfo'; echo '') >>taginfo"
 cvs_file add taginfo
 
-if [ ".$CVS_VENDOR" = .OSSP ]; then
+if [ ".$CVS_VENDOR" = .RSE ]; then
     cvs_file tst importinfo
     run "(echo ''; echo 'ALL $V_tool_shiela --hook=importinfo'; echo '') >>importinfo"
     cvs_file add importinfo
@@ -612,7 +612,7 @@ cvs_file tst verifymsg
 run "(echo ''; echo 'DEFAULT $V_tool_shiela --hook=verifymsg'; echo '') >>verifymsg"
 cvs_file add verifymsg
 
-if [ ".$CVS_VENDOR" = .OSSP ]; then
+if [ ".$CVS_VENDOR" = .RSE ]; then
     flags="sVvto"
 else
     flags="sVv"
